from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0005_formats'),
    ]

    operations = [
        migrations.RunPython(migrations.RunPython.noop),
    ]



# Generated by Django 3.2.13 on 2022-05-24 20:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0131_auto_20220420_1535'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cameramodel',
            name='other_names',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='other_names',
        ),
    ]



# Generated by Django 3.2.12 on 2022-03-31 15:33

import colorfield.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0129_auto_20211109_2120'),
    ]

    operations = [
        migrations.AddField(
            model_name='filter',
            name='colour',
            field=colorfield.fields.ColorField(blank=True, default=None, help_text='Colour of the filter', image_field=None, max_length=18, null=True, samples=None),
        ),
    ]



# Generated by Django 3.2.13 on 2022-05-24 20:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0132_auto_20220524_2017'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='battery_type',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='fastest_shutter_speed',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='format',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='lens_manufacturer',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='manufacturer',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='mount',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='negative_size',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='slowest_shutter_speed',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='x_sync',
        ),
        migrations.RemoveField(
            model_name='historicaldeveloper',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='historicaldeveloper',
            name='manufacturer',
        ),
        migrations.RemoveField(
            model_name='historicalenlargermodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='historicalenlargermodel',
            name='manufacturer',
        ),
        migrations.RemoveField(
            model_name='historicalenlargermodel',
            name='negative_size',
        ),
        migrations.RemoveField(
            model_name='historicalfilmstock',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='historicalfilmstock',
            name='manufacturer',
        ),
        migrations.RemoveField(
            model_name='historicalfilmstock',
            name='process',
        ),
        migrations.RemoveField(
            model_name='historicalflashmodel',
            name='battery_type',
        ),
        migrations.RemoveField(
            model_name='historicalflashmodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='historicalflashmodel',
            name='manufacturer',
        ),
        migrations.RemoveField(
            model_name='historicalformat',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='historicallensmodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='historicallensmodel',
            name='manufacturer',
        ),
        migrations.RemoveField(
            model_name='historicallensmodel',
            name='mount',
        ),
        migrations.RemoveField(
            model_name='historicallensmodel',
            name='negative_size',
        ),
        migrations.RemoveField(
            model_name='historicalmanufacturer',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='historicalmount',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='historicalmount',
            name='manufacturer',
        ),
        migrations.RemoveField(
            model_name='historicalnegativesize',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='historicalpaperstock',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='historicalpaperstock',
            name='manufacturer',
        ),
        migrations.RemoveField(
            model_name='historicalprocess',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='historicalteleconvertermodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='historicalteleconvertermodel',
            name='manufacturer',
        ),
        migrations.RemoveField(
            model_name='historicalteleconvertermodel',
            name='mount',
        ),
        migrations.RemoveField(
            model_name='historicaltoner',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='historicaltoner',
            name='manufacturer',
        ),
        migrations.DeleteModel(
            name='HistoricalBattery',
        ),
        migrations.DeleteModel(
            name='HistoricalCameraModel',
        ),
        migrations.DeleteModel(
            name='HistoricalDeveloper',
        ),
        migrations.DeleteModel(
            name='HistoricalEnlargerModel',
        ),
        migrations.DeleteModel(
            name='HistoricalFilmStock',
        ),
        migrations.DeleteModel(
            name='HistoricalFlashModel',
        ),
        migrations.DeleteModel(
            name='HistoricalFormat',
        ),
        migrations.DeleteModel(
            name='HistoricalLensModel',
        ),
        migrations.DeleteModel(
            name='HistoricalManufacturer',
        ),
        migrations.DeleteModel(
            name='HistoricalMount',
        ),
        migrations.DeleteModel(
            name='HistoricalNegativeSize',
        ),
        migrations.DeleteModel(
            name='HistoricalPaperStock',
        ),
        migrations.DeleteModel(
            name='HistoricalProcess',
        ),
        migrations.DeleteModel(
            name='HistoricalTeleconverterModel',
        ),
        migrations.DeleteModel(
            name='HistoricalToner',
        ),
    ]



# Generated by Django 3.2.12 on 2022-04-20 15:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0130_filter_colour'),
    ]

    operations = [
        migrations.AddField(
            model_name='historicallensmodel',
            name='purpose',
            field=models.CharField(blank=True, choices=[('Camera', 'Camera'), ('Enlarger', 'Enlarger'), ('Projector', 'Projector')], help_text='Intended purposes of lens', max_length=16, null=True),
        ),
        migrations.AddField(
            model_name='lensmodel',
            name='purpose',
            field=models.CharField(blank=True, choices=[('Camera', 'Camera'), ('Enlarger', 'Enlarger'), ('Projector', 'Projector')], help_text='Intended purposes of lens', max_length=16, null=True),
        ),
    ]



from django.db import migrations

class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0069_auto_20200810_1812'),
    ]

    operations = [
        # omit reverse_code=... if you don't want the migration to be reversible.
        migrations.RunPython(migrations.RunPython.noop,
                             reverse_code=migrations.RunPython.noop),
    ]



from __future__ import unicode_literals
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ('schema', '0101_negative_slug'),
    ]
    operations = [
        migrations.RunPython(
            migrations.RunPython.noop, reverse_code=migrations.RunPython.noop),

    ]
